mcwb - A Minecraft world builder library
========================================

`mcwb` is a Python 3 library, which provides functions to manipulate Minecraft worlds via `RCON <http://wiki.vg/RCON>`_ commands.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   scripts
   mcwb
   bugs
   license


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
